==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetApplicationDateRangeKpiRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.{__timestampIso8601, __string}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class GetApplicationDateRangeKpiRequest(
    applicationId: __string,
    endTime: Option[__timestampIso8601] = None,
    kpiName: __string,
    nextToken: Option[__string] = None,
    pageSize: Option[__string] = None,
    startTime: Option[__timestampIso8601] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest = {
    import GetApplicationDateRangeKpiRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .optionallyWith(
        endTime.map(value => __timestampIso8601.unwrap(value): Instant)
      )(_.endTime)
      .kpiName(__string.unwrap(kpiName): java.lang.String)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        pageSize.map(value => __string.unwrap(value): java.lang.String)
      )(_.pageSize)
      .optionallyWith(
        startTime.map(value => __timestampIso8601.unwrap(value): Instant)
      )(_.startTime)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest.ReadOnly =
    zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest
      .wrap(buildAwsValue())
}
object GetApplicationDateRangeKpiRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest =
      zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest(
        applicationId,
        endTime.map(value => value),
        kpiName,
        nextToken.map(value => value),
        pageSize.map(value => value),
        startTime.map(value => value)
      )
    def applicationId: __string
    def endTime: Option[__timestampIso8601]
    def kpiName: __string
    def nextToken: Option[__string]
    def pageSize: Option[__string]
    def startTime: Option[__timestampIso8601]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getEndTime: ZIO[Any, AwsError, __timestampIso8601] =
      AwsError.unwrapOptionField("endTime", endTime)
    def getKpiName: ZIO[Any, Nothing, __string] = ZIO.succeed(kpiName)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getPageSize: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("pageSize", pageSize)
    def getStartTime: ZIO[Any, AwsError, __timestampIso8601] =
      AwsError.unwrapOptionField("startTime", startTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest
  ) extends zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val endTime: Option[__timestampIso8601] = scala
      .Option(impl.endTime())
      .map(value => zio.aws.pinpoint.model.primitives.__timestampIso8601(value))
    override val kpiName: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.kpiName())
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
    override val pageSize: Option[__string] = scala
      .Option(impl.pageSize())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
    override val startTime: Option[__timestampIso8601] = scala
      .Option(impl.startTime())
      .map(value => zio.aws.pinpoint.model.primitives.__timestampIso8601(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest
  ): zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/GetApplicationDateRangeKpiRequest.scala <==
package zio.aws.pinpoint.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.pinpoint.model.primitives.{__timestampIso8601, __string}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class GetApplicationDateRangeKpiRequest(
    applicationId: __string,
    endTime: Optional[__timestampIso8601] = Optional.Absent,
    kpiName: __string,
    nextToken: Optional[__string] = Optional.Absent,
    pageSize: Optional[__string] = Optional.Absent,
    startTime: Optional[__timestampIso8601] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest = {
    import GetApplicationDateRangeKpiRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .optionallyWith(endTime.map(value => value: Instant))(_.endTime)
      .kpiName(kpiName: java.lang.String)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(pageSize.map(value => value: java.lang.String))(
        _.pageSize
      )
      .optionallyWith(startTime.map(value => value: Instant))(_.startTime)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest.ReadOnly =
    zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest
      .wrap(buildAwsValue())
}
object GetApplicationDateRangeKpiRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest =
      zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest(
        applicationId,
        endTime.map(value => value),
        kpiName,
        nextToken.map(value => value),
        pageSize.map(value => value),
        startTime.map(value => value)
      )
    def applicationId: __string
    def endTime: Optional[__timestampIso8601]
    def kpiName: __string
    def nextToken: Optional[__string]
    def pageSize: Optional[__string]
    def startTime: Optional[__timestampIso8601]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getEndTime: ZIO[Any, AwsError, __timestampIso8601] =
      AwsError.unwrapOptionField("endTime", endTime)
    def getKpiName: ZIO[Any, Nothing, __string] = ZIO.succeed(kpiName)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getPageSize: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("pageSize", pageSize)
    def getStartTime: ZIO[Any, AwsError, __timestampIso8601] =
      AwsError.unwrapOptionField("startTime", startTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest
  ) extends zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val endTime: Optional[__timestampIso8601] = zio.aws.core.internal
      .optionalFromNullable(impl.endTime())
      .map(value => value: __timestampIso8601)
    override val kpiName: __string = impl.kpiName(): __string
    override val nextToken: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: __string)
    override val pageSize: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.pageSize())
      .map(value => value: __string)
    override val startTime: Optional[__timestampIso8601] = zio.aws.core.internal
      .optionalFromNullable(impl.startTime())
      .map(value => value: __timestampIso8601)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetApplicationDateRangeKpiRequest
  ): zio.aws.pinpoint.model.GetApplicationDateRangeKpiRequest.ReadOnly =
    new Wrapper(impl)
}
